<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>CloudNotifications</name>
    <message>
        <location filename="../libnymea-core/cloud/cloudnotifications.cpp" line="57"/>
        <location filename="../libnymea-core/cloud/cloudnotifications.cpp" line="121"/>
        <source>Cloud Notifications</source>
        <translation>Notificaciones en la nube</translation>
    </message>
    <message>
        <location filename="../libnymea-core/cloud/cloudnotifications.cpp" line="69"/>
        <source>User ID</source>
        <translation>Identificación de usuario</translation>
    </message>
    <message>
        <location filename="../libnymea-core/cloud/cloudnotifications.cpp" line="75"/>
        <source>Device</source>
        <translation>Dispositivo</translation>
    </message>
    <message>
        <location filename="../libnymea-core/cloud/cloudnotifications.cpp" line="85"/>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <location filename="../libnymea-core/cloud/cloudnotifications.cpp" line="91"/>
        <source>Message text</source>
        <translation>Texto de mensaje</translation>
    </message>
    <message>
        <location filename="../libnymea-core/cloud/cloudnotifications.cpp" line="101"/>
        <source>Send notification</source>
        <translation>Enviar notificación</translation>
    </message>
    <message>
        <location filename="../libnymea-core/cloud/cloudnotifications.cpp" line="110"/>
        <source>connected</source>
        <translation>conectado</translation>
    </message>
</context>
<context>
    <name>ThingManagerImplementation</name>
    <message>
        <location filename="../libnymea-core/integrations/thingmanagerimplementation.cpp" line="305"/>
        <location filename="../libnymea-core/integrations/thingmanagerimplementation.cpp" line="2086"/>
        <source>The plugin for this thing is not loaded.</source>
        <translation>El complemento para este elemento no está cargado.</translation>
    </message>
</context>
<context>
    <name>nymea</name>
    <message>
        <location filename="../server/main.cpp" line="87"/>
        <source>
nymea is an open source IoT (Internet of Things) server, 
which allows to control a lot of different devices from many different 
manufacturers. With the powerful rule engine you are able to connect any 
device available in the system and create individual scenes and behaviors 
for your environment.

</source>
        <translation>
nymea es un servidor de código abierto IoT (Internet de las cosas) que permite controlar multitud de diferentes dispositivos de diversos fabricantes. Podrá conectarse a cualquier dispositivo disponible en el sistema con el motor potente de normas y crear casos y comportamientos individuales en su entorno.

</translation>
    </message>
    <message>
        <location filename="../server/main.cpp" line="99"/>
        <source>Run nymead in the foreground, not as daemon.</source>
        <translation>Ejecute nymea en primer plano, no como daemon.</translation>
    </message>
    <message>
        <location filename="../server/main.cpp" line="102"/>
        <source>Disables logging all debug, info and warning categories.</source>
        <translation>Desactiva el registro de todas las categorías de depuración, información y advertencia.</translation>
    </message>
    <message>
        <location filename="../server/main.cpp" line="105"/>
        <source>Enables all info and debug categories except *Traffic and *Debug categories.</source>
        <translation>Activa todas las categorías de información y depuración excepto las categorías *Traffic y *Debug.</translation>
    </message>
    <message>
        <location filename="../server/main.cpp" line="108"/>
        <source>Specify a log file to write to, if this option is not specified, logs will be printed to the standard output.</source>
        <translation>Especifique un archivo de registro en el que escribir, si esta opción no está especificada, se imprimirán los registros de forma estándar.</translation>
    </message>
    <message>
        <location filename="../server/main.cpp" line="111"/>
        <source>Log output is colorized by default. Use this option to disable colors.</source>
        <translation>La salida del registro se colorea de forma predeterminada. Usa esta opción para desactivar los colores.</translation>
    </message>
    <message>
        <location filename="../server/main.cpp" line="114"/>
        <source>If specified, all D-Bus interfaces will be bound to the session bus instead of the system bus.</source>
        <translation>Si se ha especificado, todas las interfaces D-Bus estarán conectadas a la sesión en lugar de al bus de sistema.</translation>
    </message>
    <message>
        <location filename="../server/main.cpp" line="117"/>
        <source>Debug categories to enable. Prefix with &quot;No&quot; to disable. Suffix with &quot;Info&quot; or &quot;Warnings&quot; to address info and warning messages. Enabling a debug category will implicitly enable the according info category.
Examples:
-d ThingManager
-d NoApplicationInfo

</source>
        <translation>Categorías de depuración que se van a activar. Antepon &quot;No&quot; para desactivarlas. Añade el sufijo &quot;Info&quot; o &quot;Warnings&quot; para dirigir los mensajes de información y advertencia. Al habilitar una categoría de depuración se habilita implícitamente la categoría de información correspondiente.
Ejemplos:
-d ThingManager
-d NoApplicationInfo
</translation>
    </message>
    <message>
        <location filename="../server/main.cpp" line="121"/>
        <source>Additional interfaces to listen on. In nymea URI format (e.g. nymeas://127.0.0.2:7777). Note that such interfaces will not require any authentication as they are intended to be used for automated testing only.</source>
        <translation>Interfaces adicionales en las que escuchar. En formato URI de nymea (por ejemplo nymeas://127.0.0.2:7777). Ten en cuenta que dichas interfaces no requerirán autenticación, ya que están pensadas solo para pruebas automatizadas.</translation>
    </message>
</context>
<context>
    <name>nymeaserver::DebugServerHandler</name>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="901"/>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1941"/>
        <source>Debug nymea</source>
        <extracomment>The header title of the debug server interface</extracomment>
        <translation>Eliminación de fallos de nymea</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="918"/>
        <source>nymea debug interface</source>
        <extracomment>The main title of the debug server interface</extracomment>
        <translation>Interfaz de eliminación de fallos de nymea</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="931"/>
        <source>Information</source>
        <extracomment>The name of the section tab in the debug server interface</extracomment>
        <translation>Información</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="947"/>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1674"/>
        <source>Network</source>
        <extracomment>The name of the section tab in the debug server interface
----------
The network section of the debug interface</extracomment>
        <translation>Red</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="991"/>
        <source>Server information</source>
        <extracomment>The server information section of the debug interface</extracomment>
        <translation>Información del servidor</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1046"/>
        <source>User</source>
        <extracomment>The user name in the server infromation section of the debug interface</extracomment>
        <translation>Usuario</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1058"/>
        <source>Compiled with Qt version</source>
        <extracomment>The Qt build version description in the server infromation section of the debug interface</extracomment>
        <translation>Elaborado con la versión Qt</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1064"/>
        <source>Qt runtime version</source>
        <extracomment>The Qt runtime version description in the server infromation section of the debug interface</extracomment>
        <translation>Versión de tiempo de ejecución Qt</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1052"/>
        <source>Command</source>
        <extracomment>The command description in the server infromation section of the debug interface</extracomment>
        <translation>Comando</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1073"/>
        <source>Snap name</source>
        <extracomment>The snap name description in the server infromation section of the debug interface</extracomment>
        <translation>Nombre de Snap</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1079"/>
        <source>Snap version</source>
        <extracomment>The snap version description in the server infromation section of the debug interface</extracomment>
        <translation>Versión de Snap</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1085"/>
        <source>Snap directory</source>
        <extracomment>The snap directory description in the server infromation section of the debug interface</extracomment>
        <translation>Directorio de Snap</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1091"/>
        <source>Snap application data</source>
        <extracomment>The snap application data description in the server infromation section of the debug interface</extracomment>
        <translation>Datos de aplicación de Snap</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1097"/>
        <source>Snap user data</source>
        <extracomment>The snap user data description in the server infromation section of the debug interface</extracomment>
        <translation>Datos de usuario de Snap</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1103"/>
        <source>Snap common data</source>
        <extracomment>The snap common data description in the server infromation section of the debug interface</extracomment>
        <translation>Datos comunes de Snap</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="998"/>
        <source>Server name</source>
        <extracomment>The server name description in the server infromation section of the debug interface</extracomment>
        <translation>Nombre del servidor</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1004"/>
        <source>Server version</source>
        <extracomment>The server version description in the server infromation section of the debug interface</extracomment>
        <translation>Versión del servidor</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1010"/>
        <source>JSON-RPC version</source>
        <extracomment>The API version description in the server infromation section of the debug interface</extracomment>
        <translation>Versión JSON-RPC</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1016"/>
        <source>Language</source>
        <extracomment>The language description in the server infromation section of the debug interface</extracomment>
        <translation>Idioma</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1022"/>
        <source>Timezone</source>
        <extracomment>The timezone description in the server infromation section of the debug interface</extracomment>
        <translation>Zona horaria</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1028"/>
        <source>Server UUID</source>
        <extracomment>The server id description in the server infromation section of the debug interface</extracomment>
        <translation>Servidor UUID</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1034"/>
        <source>Settings path</source>
        <extracomment>The settings path description in the server infromation section of the debug interface</extracomment>
        <translation>Ruta de ajustes</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1040"/>
        <source>Translations path</source>
        <extracomment>The translation path description in the server infromation section of the debug interface</extracomment>
        <translation>Ruta de traducciones</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1165"/>
        <source>Generate report</source>
        <extracomment>In the server information section of the debug interface</extracomment>
        <translation>Generar informe</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1168"/>
        <source>If you want to provide all the debug information to a developer, you can generate a report file, which contains all information needed for reproducing a system and get information about possible problems.</source>
        <translation>Si quieres proporcionar toda la información de depuración a un desarrollador, puedes generar un archivo de informe que contenga toda la información necesaria para reproducir un sistema y detectar posibles problemas.</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1196"/>
        <source>Generate report file</source>
        <extracomment>The generate debug report button text of the debug interface</extracomment>
        <translation>Generar archivo de informe</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1234"/>
        <source>Log database</source>
        <extracomment>The log databse download description of the debug interface</extracomment>
        <translation>Base da datos de registro</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1370"/>
        <source>Thing settings</source>
        <extracomment>The thing settings download description of the debug interface</extracomment>
        <translation>Configuración del elemento</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1742"/>
        <source>This test shows the trace path from the nymea device to the nymea.io server.</source>
        <translation>Esta prueba muestra la ruta de trazado desde el dispositivo nymea hasta el servidor nymea.io.</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1781"/>
        <source>This section allows you to see the live logs of the nymea server.</source>
        <translation>Esta sección te permite ver los registros en vivo del servidor nymea.</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="939"/>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1218"/>
        <source>Downloads</source>
        <extracomment>The name of the section tab in the debug server interface
----------
The downloads section of the debug interface</extracomment>
        <translation>Descargas</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="955"/>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1223"/>
        <source>Logs</source>
        <extracomment>The name of the section tab in the debug server interface
----------
The download logs section of the debug interface</extracomment>
        <translation>Registros</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="983"/>
        <source>Please note that this debug interface may allow accessing sensitive data about the nymea system and connected devices and services. It is recommended to disable it again when not needed any more.</source>
        <extracomment>The warning message of the debug interface</extracomment>
        <translation>Ten en cuenta que esta interfaz de depuración puede permitir el acceso a datos confidenciales sobre el sistema nymea y los dispositivos y servicios conectados. Se recomienda desactivarla de nuevo cuando ya no se necesite.</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1114"/>
        <source>System information</source>
        <extracomment>The system information section of the debug interface</extracomment>
        <translation>Información del sistema</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1121"/>
        <source>Hostname</source>
        <extracomment>The command description in the server infromation section of the debug interface</extracomment>
        <translation>Nombre de host</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1132"/>
        <source>Architecture</source>
        <extracomment>The command description in the server infromation section of the debug interface</extracomment>
        <translation>Arquitectura</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1138"/>
        <source>Kernel type</source>
        <extracomment>The command description in the server infromation section of the debug interface</extracomment>
        <translation>Tipo de kernel</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1144"/>
        <source>Kernel version</source>
        <extracomment>The command description in the server infromation section of the debug interface</extracomment>
        <translation>Versión del kernel</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1150"/>
        <source>Product type</source>
        <extracomment>The command description in the server infromation section of the debug interface</extracomment>
        <translation>Tipo de producto</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1156"/>
        <source>Product version</source>
        <extracomment>The command description in the server infromation section of the debug interface</extracomment>
        <translation>Versión del producto</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1185"/>
        <source>Please note that the generated debug report may contain sensitive data about the nymea system and connected devices and services.</source>
        <extracomment>The warning message of the debug interface</extracomment>
        <translation>Ten en cuenta que el informe de depuración generado puede contener datos confidenciales sobre el sistema nymea y los dispositivos y servicios conectados.</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1256"/>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1286"/>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1339"/>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1389"/>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1439"/>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1489"/>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1539"/>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1588"/>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1638"/>
        <source>Download</source>
        <extracomment>The download button description of the debug interface</extracomment>
        <translation>Descarga</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1270"/>
        <source>System logs</source>
        <extracomment>The syslog download description of the debug interface</extracomment>
        <translation>Registros de sistema</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1299"/>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1355"/>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1405"/>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1455"/>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1505"/>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1555"/>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1604"/>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1654"/>
        <source>Show</source>
        <translation>Mostrar</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1310"/>
        <source>Settings</source>
        <extracomment>The settings download section title of the debug interface</extracomment>
        <translation>Ajustes</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1320"/>
        <source>nymead settings</source>
        <extracomment>The nymead settings download description of the debug interface</extracomment>
        <translation>Ajustes nymea</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1420"/>
        <source>Rules settings</source>
        <extracomment>The rules settings download description of the debug interface</extracomment>
        <translation>Ajustes de normas</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1470"/>
        <source>Plugins settings</source>
        <extracomment>The plugins settings download description of the debug interface</extracomment>
        <translation>Ajustes de plugins</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1520"/>
        <source>Tag settings</source>
        <extracomment>The tag settings download description of the debug interface</extracomment>
        <translation>Configuración de etiquetas</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1569"/>
        <source>MQTT policies</source>
        <extracomment>The MQTT policies download description of the debug interface</extracomment>
        <translation>Políticas MQTT</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1619"/>
        <source>IO Connections</source>
        <extracomment>The MQTT policies download description of the debug interface</extracomment>
        <translation>Conexiones IO</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1677"/>
        <source>This section allows you to perform different network connectivity tests in order to find out if the device where nymea is running has full network connectivity.</source>
        <extracomment>The network section description of the debug interface</extracomment>
        <translation>Esta sección te permite realizar diferentes pruebas de conectividad de red para averiguar si el dispositivo donde se ejecuta nymea tiene conectividad de red completa.</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1683"/>
        <source>Ping</source>
        <extracomment>The ping section of the debug interface</extracomment>
        <translation>Ping</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1686"/>
        <source>This test makes four ping attempts to the nymea.io server.</source>
        <translation>Esta prueba realiza cuatro intentos de ping al servidor nymea.io.</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1695"/>
        <source>Start ping test</source>
        <extracomment>The ping button text of the debug interface</extracomment>
        <translation>Iniciar prueba de ping</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1711"/>
        <source>DNS lookup</source>
        <extracomment>The DNS lookup section of the debug interface</extracomment>
        <translation>Búsqueda DNS</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1714"/>
        <source>This test makes a dynamic name server lookup for nymea.io.</source>
        <translation>Esta prueba realiza una consulta dinámica de nombres para nymea.io.</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1724"/>
        <source>Start DNS lookup test</source>
        <extracomment>The ping button text of the debug interface</extracomment>
        <translation>Iniciar prueba de búsqueda DNS</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1739"/>
        <source>Trace path</source>
        <extracomment>The trace section of the debug interface</extracomment>
        <translation>Ruta de trazado</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1751"/>
        <source>Start trace path test</source>
        <extracomment>The trace path button text of the debug interface</extracomment>
        <translation>Iniciar prueba de ruta de trazado</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1778"/>
        <source>Server live logs</source>
        <extracomment>The network section of the debug interface</extracomment>
        <translation>Registros en vivo del servidor</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1793"/>
        <source>Start logs</source>
        <extracomment>The connect button for the log stream of the debug interface</extracomment>
        <translation>Iniciar registros</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1832"/>
        <source>Logging filters</source>
        <extracomment>The network section of the debug interface</extracomment>
        <translation>Filtros de registro</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1871"/>
        <source>Logging filters plugins</source>
        <extracomment>The network section of the debug interface</extracomment>
        <translation>Filtros de registro de complementos</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1910"/>
        <source>Released under the GNU GENERAL PUBLIC LICENSE Version 3.</source>
        <extracomment>The footer license note of the debug interface</extracomment>
        <translation>Publicado bajo la GNU GENERAL PUBLIC LICENSE Versión 3.</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1984"/>
        <source>Released under the GNU GENERAL PUBLIC LICENSE Version 2.</source>
        <translation>Publicado en la LICENCIA PÚBLICA GENERAL GNU, versión 2.</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="1954"/>
        <source>Error  %1</source>
        <extracomment>The HTTP error message of the debug interface. The %1 represents the error code ie.e 404</extracomment>
        <translation>Error  1%</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="88"/>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="120"/>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="151"/>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="180"/>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="209"/>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="239"/>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="268"/>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="298"/>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="327"/>
        <source>Could not find file &quot;%1&quot;.</source>
        <extracomment>The HTTP error message of the debug interface. The %1 represents the file name.</extracomment>
        <translation>Imposible encontrar el archivo &quot;%1&quot;.</translation>
    </message>
    <message>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="97"/>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="128"/>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="159"/>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="188"/>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="217"/>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="247"/>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="276"/>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="306"/>
        <location filename="../libnymea-core/debugserverhandler.cpp" line="335"/>
        <source>Could not open file &quot;%1&quot;.</source>
        <extracomment>The HTTP error message of the debug interface. The %1 represents the file name.</extracomment>
        <translation>Imposible abrir el archivo &quot;%1&quot;.</translation>
    </message>
</context>
</TS>
